@@ -1,13 +1,13 @@
 """
     Django Async implementation.
 """
-import logging as _logger
 
 
-def schedule(*a, **kw):
+def schedule(*a, **kw): # pragma: no cover
     """Wrapper for async.schedule.schedule that allow coverage.
     """
     # Redefining name 'schedule' from outer scope
     # pylint: disable=W0621
     from async.api import schedule
     return schedule(*a, **kw)
+
