@@ -1,13 +1,18 @@
 """
     Tests for the Django management commands.
 """
-from datetime import datetime
 from django.core import management
 from django.test import TestCase
+try:
+    # No name 'timezone' in module 'django.utils'
+    # pylint: disable=E0611
+    from django.utils import timezone as datetime
+except ImportError:
+    from datetime import datetime
 from mock import patch
 
 from async import schedule
-from async.api import health
+from async.api import health, deschedule
 from async.models import Job
 
 
@@ -103,6 +108,16 @@ class TestFlushQueue(TestCase):
         management.call_command('flush_queue')
         self.assertEqual(Job.objects.filter(executed=None).count(), 5)
 
+    def test_flush_queue_with_cancelled_jobs__should_not_be_executed(self):
+        """Make sure that the number of job run by default is 300.
+        """
+        for _ in xrange(5):
+            job = schedule(_dummy)
+            deschedule(job.name)
+        management.call_command('flush_queue')
+        self.assertEqual(Job.objects.filter(executed=None).count(), 5)
+        self.assertEqual(Job.objects.filter(cancelled=None).count(), 0)
+
 
 class TestHealth(TestCase):
     """Make sure the health command runs without any errors.
